package Acme::JAPH;
$Acme::JAPH::VERSION = '0.02';
print "Just another Perl hacker,\n";
exit;

=pod

=head1 NAME

Acme::JAPH - Turn anything into a JAPH

=head1 SYNOPSIS

    use Acme::JAPH
    a;ltiucqpoc3iqp04tu1 -394t8[ieufea[=09E U 0ET 9u [4tu]]]

=head1 DESCRIPTION

C<Acme::JAPH> turns anything into a JAPH.  Very useful, and simple.

=head1 AUTHOR

Casey West <F<casey@geeknest.com>>

=head1 COPYRIGHT

Copyright (c) 2003 Casey West, All Rights Reserved.
This module is released under the same terms as Perl itself.

=cut

